@@ -65,6 +65,9 @@ _ = gpodder.gettext
 N_ = gpodder.ngettext
 
 
+import locale
+locale.setlocale(locale.LC_ALL, '')
+
 # Native filesystem encoding detection
 encoding = sys.getfilesystemencoding()
 
@@ -433,7 +436,7 @@ def format_date(timestamp):
 
     if diff < 7:
         # Weekday name
-        return str(timestamp.strftime('%A'))
+        return str(timestamp.strftime('%A').decode(encoding))
     else:
         # Locale's appropriate date representation
         return str(timestamp.strftime('%x'))
@@ -1459,13 +1462,6 @@ def run_external_command(command_line):
     call the notification function with two arguments - the
     first being the error message and the second being the
     title to be used for the error message.
-
-    >>> from minimock import mock, Mock, restore
-    >>> mock('subprocess.Popen', returns=Mock('subprocess.Popen'))
-    >>> run_external_command('testprogramm')
-    Called subprocess.Popen('testprogramm', shell=True)
-    Called subprocess.Popen.wait()
-    >>> restore()
     """
 
     def open_process(command_line):
